diff stringlengths 65 26.7k | message stringlengths 7 9.92k |
|---|---|
diff --git a/eureka-client/src/main/java/com/netflix/appinfo/ApplicationInfoManager.java b/eureka-client/src/main/java/com/netflix/appinfo/ApplicationInfoManager.java
index <HASH>..<HASH> 100644
--- a/eureka-client/src/main/java/com/netflix/appinfo/ApplicationInfoManager.java
+++ b/eureka-client/src/main/java/com/netflix/appinfo/ApplicationInfoManager.java
@@ -56,7 +56,7 @@ public class ApplicationInfoManager {
}
@Inject
- ApplicationInfoManager(EurekaInstanceConfig config, InstanceInfo instanceInfo) {
+ public ApplicationInfoManager(EurekaInstanceConfig config, InstanceInfo instanceInfo) {
this.config = config;
this.instanceInfo = instanceInfo; | make constructor public so other DI systems can create instances |
diff --git a/protempa-framework/src/main/java/org/protempa/proposition/Context.java b/protempa-framework/src/main/java/org/protempa/proposition/Context.java
index <HASH>..<HASH> 100644
--- a/protempa-framework/src/main/java/org/protempa/proposition/Context.java
+++ b/protempa-framework/src/main/java/org/protempa/proposition/Context.java
@@ -50,12 +50,12 @@ public final class Context extends TemporalProposition implements Serializable {
@Override
public void accept(PropositionVisitor propositionVisitor) {
- throw new UnsupportedOperationException("Unimplemented");
+ propositionVisitor.visit(this);
}
@Override
public void acceptChecked(PropositionCheckedVisitor propositionCheckedVisitor) throws ProtempaException {
- throw new UnsupportedOperationException("Unimplemented");
+ propositionCheckedVisitor.visit(this);
}
private void writeObject(ObjectOutputStream s) throws IOException { | Implemented accept and acceptChecked. |
diff --git a/pysolr.py b/pysolr.py
index <HASH>..<HASH> 100644
--- a/pysolr.py
+++ b/pysolr.py
@@ -608,6 +608,9 @@ class Solr(object):
continue
if boost and v in boost:
+ if not isinstance(boost, basestring):
+ boost[v] = str(boost[v])
+
f = ET.Element('field', name=key, boost=boost[v])
else:
f = ET.Element('field', name=key)
@@ -620,6 +623,9 @@ class Solr(object):
continue
if boost and key in boost:
+ if not isinstance(boost, basestring):
+ boost[v] = str(boost[v])
+
f = ET.Element('field', name=key, boost=boost[key])
else:
f = ET.Element('field', name=key) | Boost values are now coerced into a string. Thanks to notanumber for the patch! |
diff --git a/lib/lanes/api/sprockets_extension.rb b/lib/lanes/api/sprockets_extension.rb
index <HASH>..<HASH> 100644
--- a/lib/lanes/api/sprockets_extension.rb
+++ b/lib/lanes/api/sprockets_extension.rb
@@ -4,6 +4,8 @@ require 'sinatra/sprockets-helpers'
require_relative 'javascript_processor'
require 'compass/import-once/activate'
require 'sprockets-helpers'
+require 'tilt/erb'
+require 'compass/import-once/activate'
module Lanes
module API | require tilt/erb and import-once |
diff --git a/cli/index.js b/cli/index.js
index <HASH>..<HASH> 100755
--- a/cli/index.js
+++ b/cli/index.js
@@ -12,9 +12,6 @@ process.env.VERBOSE =
let cmd = process.argv[2]
switch(cmd) {
- case '.': // Watch current root
- watch(process.cwd())
- break
case 'start': // Start the daemon
let starting = wch.start()
if (starting) {
@@ -65,6 +62,10 @@ switch(cmd) {
v: true, // verbose errors
})
+ // Watch the current directory.
+ if (args._ == '.')
+ return watch(process.cwd())
+
if (Array.isArray(args.x) && !args.w)
fatal('Cannot use -x without -w') | fix(cli): fail if wch . has any flags |
diff --git a/lib/dalli/server.rb b/lib/dalli/server.rb
index <HASH>..<HASH> 100644
--- a/lib/dalli/server.rb
+++ b/lib/dalli/server.rb
@@ -59,7 +59,7 @@ module Dalli
end
connect
- @sock
+ !!@sock
rescue Dalli::NetworkError
false
end | make server#alive? always return a boolean value |
diff --git a/src/dpt/index.js b/src/dpt/index.js
index <HASH>..<HASH> 100644
--- a/src/dpt/index.js
+++ b/src/dpt/index.js
@@ -22,7 +22,7 @@ class DPT extends EventEmitter {
this._kbucket = new KBucket(this._id)
this._kbucket.on('added', (peer) => this.emit('peer:added', peer))
- this._kbucket.on('remove', (peer) => this.emit('peer:removed', peer))
+ this._kbucket.on('removed', (peer) => this.emit('peer:removed', peer))
this._kbucket.on('ping', (...args) => this._onKBucketPing(...args))
this._server = new DPTServer(this, this._privateKey, { | Fix bug not forwarding k-bucket remove event through DPT |
diff --git a/lib/run/index.js b/lib/run/index.js
index <HASH>..<HASH> 100644
--- a/lib/run/index.js
+++ b/lib/run/index.js
@@ -132,10 +132,15 @@ Runner.prototype.initFramework = function() {
testProcess.stderr.setEncoding('utf8');
testProcess.stdout.on('data', data => {
+ if (typeof data === 'string') {
+ data = data.replace(/\r?\n|\r$/, '');
+ }
this.emit('data', data);
});
-
testProcess.stderr.on('data', data => {
+ if (typeof data === 'string') {
+ data = data.replace(/\r?\n|\r$/, '');
+ }
this.emit('data', data);
}); | fix(logging): fix empty links between test cases (#<I>) |
diff --git a/src/objects/message.aspec.js b/src/objects/message.aspec.js
index <HASH>..<HASH> 100644
--- a/src/objects/message.aspec.js
+++ b/src/objects/message.aspec.js
@@ -283,4 +283,21 @@ describe("./objects/message.js", function () {
});
+ it("msngr().persist().cease().on() - registers a payload, unregisters a payload then registers a handler", function (done) {
+ var handledCount = 0;
+
+ var msg = msngr("MyTestingTopic");
+ msg.persist("MyPayload");
+ msg.cease();
+ msg.on(function (payload) {
+ ++handledCount;
+ });
+
+ setTimeout(function () {
+ expect(handledCount).to.equal(0);
+ done();
+ }, 250);
+
+ });
+
}); | Added unit test to cover cease correctly |
diff --git a/src/Slim/Handlers/Strategies/ActionStrategy.php b/src/Slim/Handlers/Strategies/ActionStrategy.php
index <HASH>..<HASH> 100644
--- a/src/Slim/Handlers/Strategies/ActionStrategy.php
+++ b/src/Slim/Handlers/Strategies/ActionStrategy.php
@@ -1,4 +1,5 @@
<?php
+
namespace Eukles\Slim\Handlers\Strategies;
use Eukles\Action;
@@ -76,14 +77,13 @@ class ActionStrategy implements InvocationStrategyInterface
ServerRequestInterface $request,
ResponseInterface $response,
array $routeArguments
- )
- {
-
+ ) {
+
try {
return call_user_func_array($callable, $this->buildParams($callable, $request, $routeArguments));
} catch (\Exception $e) {
$handler = $this->container->getActionErrorHandler();
-
+
return $handler($e, $request, $response);
}
}
@@ -158,6 +158,8 @@ class ActionStrategy implements InvocationStrategyInterface
$buildParams[] = $cleaner->cleanArray($paramValue);
} elseif (is_scalar($paramValue)) {
$buildParams[] = $cleaner->cleanString($paramValue);
+ } else {
+ $buildParams[] = $paramValue;
}
}
} | fix error, no scalar/array/object parameter was not injected in function since XssCleaner |
diff --git a/lxd/main.go b/lxd/main.go
index <HASH>..<HASH> 100644
--- a/lxd/main.go
+++ b/lxd/main.go
@@ -833,7 +833,7 @@ they otherwise would.
}
// Unset all storage keys, core.https_address and core.trust_password
- for _, key := range []string{"core.https_address", "core.trust_password"} {
+ for _, key := range []string{"storage.zfs_pool_name", "core.https_address", "core.trust_password"} {
_, err = c.SetServerConfig(key, "")
if err != nil {
return err | init: actually unset the storage keys |
diff --git a/course/edit.php b/course/edit.php
index <HASH>..<HASH> 100644
--- a/course/edit.php
+++ b/course/edit.php
@@ -145,7 +145,6 @@
} else { // Add current teacher and send to course
// find a role with legacy:edittingteacher
-
if ($teacherroles = get_roles_with_capability('moodle/legacy:editingteacher', CAP_ALLOW, $context)) {
// assign the role to this user
$teachereditrole = array_shift($teacherroles);
@@ -306,11 +305,11 @@ function validate_form($course, &$form, &$err) {
if (empty($form->summary))
$err["summary"] = get_string("missingsummary");
- if (empty($form->teacher))
- $err["teacher"] = get_string("missingteacher");
+ //if (empty($form->teacher))
+ // $err["teacher"] = get_string("missingteacher");
- if (empty($form->student))
- $err["student"] = get_string("missingstudent");
+ //if (empty($form->student))
+ // $err["student"] = get_string("missingstudent");
if (! $form->category)
$err["category"] = get_string("missingcategory"); | validation should not watch out for teacher and students string anymore |
diff --git a/spyder/widgets/mixins.py b/spyder/widgets/mixins.py
index <HASH>..<HASH> 100644
--- a/spyder/widgets/mixins.py
+++ b/spyder/widgets/mixins.py
@@ -697,9 +697,12 @@ class BaseEditMixin(object):
characters.
"""
text = self.toPlainText()
+ lines = text.splitlines()
linesep = self.get_line_separator()
- text.replace('\n', linesep)
- return text
+ text_with_eol = linesep.join(lines)
+ if text.endswith('\n'):
+ text_with_eol += linesep
+ return text_with_eol
#------Positions, coordinates (cursor, EOF, ...)
def get_position(self, subject): | Editor: Fix getting text with end-of-lines |
diff --git a/activeresource/test/cases/base_test.rb b/activeresource/test/cases/base_test.rb
index <HASH>..<HASH> 100644
--- a/activeresource/test/cases/base_test.rb
+++ b/activeresource/test/cases/base_test.rb
@@ -473,17 +473,6 @@ class BaseTest < ActiveSupport::TestCase
assert_equal nil, fruit.headers['key2']
end
- def test_header_inheritance_should_not_leak_upstream
- fruit = Class.new(ActiveResource::Base)
- apple = Class.new(fruit)
- fruit.site = 'http://market'
-
- fruit.headers['key'] = 'value'
-
- apple.headers['key2'] = 'value2'
- assert_equal nil, fruit.headers['key2']
- end
-
########################################################################
# Tests for setting up remote URLs for a given model (including adding
# parameters appropriately) | Remove double test for header inheritance leaks |
diff --git a/SingularityBase/src/main/java/com/hubspot/singularity/SingularityState.java b/SingularityBase/src/main/java/com/hubspot/singularity/SingularityState.java
index <HASH>..<HASH> 100644
--- a/SingularityBase/src/main/java/com/hubspot/singularity/SingularityState.java
+++ b/SingularityBase/src/main/java/com/hubspot/singularity/SingularityState.java
@@ -1,5 +1,6 @@
package com.hubspot.singularity;
+import java.util.Collections;
import java.util.List;
import com.fasterxml.jackson.annotation.JsonCreator;
@@ -121,7 +122,7 @@ public class SingularityState {
this.cleaningTasks = cleaningTasks;
this.hostStates = hostStates;
this.lateTasks = lateTasks;
- this.listLateTasks = listLateTasks;
+ this.listLateTasks = listLateTasks == null ? Collections.emptyList() : listLateTasks;
this.finishedRequests = finishedRequests;
this.futureTasks = futureTasks;
this.maxTaskLag = maxTaskLag; | handle when list of late tasks is not in json yet |
diff --git a/break_break_infinity.js b/break_break_infinity.js
index <HASH>..<HASH> 100644
--- a/break_break_infinity.js
+++ b/break_break_infinity.js
@@ -1299,6 +1299,16 @@ var padEnd = function (string, maxLength, fillString) {
tanh() {
return this.sinh().div(this.cosh());
}
+ asinh() {
+ return Decimal.ln(this.add(this.sqr().add(1).sqrt()));
+ }
+ acosh() {
+ return Decimal.ln(this.add(this.sqr().sub(1).sqrt()));
+ }
+ atanh() {
+ if (this.abs().gte(1)) return Number.NaN;
+ return Decimal.ln(this.add(1).div(new Decimal(1).sub(this))).div(2);
+ }
//If you're willing to spend 'resourcesAvailable' and want to buy something with exponentially increasing cost each purchase (start at priceStart, multiply by priceRatio, already own currentOwned), how much of it can you buy? Adapted from Trimps source code.
static affordGeometricSeries(resourcesAvailable, priceStart, priceRatio, currentOwned) | the other hyperbolic trig functions |
diff --git a/components/web.js b/components/web.js
index <HASH>..<HASH> 100644
--- a/components/web.js
+++ b/components/web.js
@@ -5,6 +5,11 @@ var Crypto = require('crypto');
var SteamCrypto = require('@doctormckay/steam-crypto');
SteamUser.prototype.webLogOn = function() {
+ // Verify logged on
+ if (!this.steamID) {
+ throw new Error("Cannot log onto steamcommunity.com without first being connected to Steam network");
+ }
+
// Verify not anonymous user
if (this.steamID.type === SteamID.Type.ANON_USER) {
throw new Error('Must not be anonymous user to use webLogOn (check to see you passed in valid credentials to logOn)') | Throw an Error if we try to webLogOn without being connected |
diff --git a/src/controllers/MoveController.php b/src/controllers/MoveController.php
index <HASH>..<HASH> 100644
--- a/src/controllers/MoveController.php
+++ b/src/controllers/MoveController.php
@@ -12,9 +12,9 @@
namespace hipanel\modules\stock\controllers;
use hipanel\actions\Action;
+use hipanel\actions\ComboSearchAction;
use hipanel\actions\IndexAction;
use hipanel\actions\OrientationAction;
-use hipanel\actions\SearchAction;
use hipanel\actions\SmartPerformAction;
use hipanel\base\CrudController;
use Yii;
@@ -41,11 +41,11 @@ class MoveController extends CrudController
},
],
'directions-list' => [
- 'class' => SearchAction::class,
+ 'class' => ComboSearchAction::class,
'on beforeSave' => function ($event) {
/** @var Action $action */
$action = $event->sender;
- $action->dataProvider->query->options['scenario'] = 'get-directions';
+ $action->dataProvider->query->action('get-directions');
},
],
'delete' => [ | MoveController - updated directions-list action to use ComboSearchAction |
diff --git a/cfg/dist.js b/cfg/dist.js
index <HASH>..<HASH> 100644
--- a/cfg/dist.js
+++ b/cfg/dist.js
@@ -31,7 +31,11 @@ const commonJsConfig = Object.assign( {}, baseConfig, {
index : path.join( __dirname, '../src/index.js' ),
componentDriver : path.join( __dirname, '../src/Testing/index.js' ),
driverSuite : path.join( __dirname, '../src/drivers.js' ),
- addons : path.join( __dirname, '../src/addons.js' )
+ addons : path.join( __dirname, '../src/addons.js' ),
+ css : [
+ path.join( __dirname, '../src/index.js' ),
+ path.join( __dirname, '../src/addons.js' ),
+ ],
},
output : {
path : path.join( __dirname, '/../dist' ), | Hack webpack/ExtractTextPlugin to combine CSS from different entrypoints #<I> |
diff --git a/setup.py b/setup.py
index <HASH>..<HASH> 100644
--- a/setup.py
+++ b/setup.py
@@ -18,7 +18,7 @@ setup(
url='http://www.metametricsinc.com/',
license='GPLv3',
install_requires=[
- 'boto3>=1.4,<1.5',
+ 'boto3>=1.4,<1.5','PyJWT==1.4.2','envs>=0.3.0'
],
extras_require={
'django': [ | Added envs and pyjwt to the setup.py |
diff --git a/src/main/java/com/j256/ormlite/android/apptools/OrmLiteSqliteOpenHelper.java b/src/main/java/com/j256/ormlite/android/apptools/OrmLiteSqliteOpenHelper.java
index <HASH>..<HASH> 100644
--- a/src/main/java/com/j256/ormlite/android/apptools/OrmLiteSqliteOpenHelper.java
+++ b/src/main/java/com/j256/ormlite/android/apptools/OrmLiteSqliteOpenHelper.java
@@ -268,7 +268,7 @@ public abstract class OrmLiteSqliteOpenHelper extends SQLiteOpenHelper {
* Get a DAO for our class. This uses the {@link DaoManager} to cache the DAO for future gets.
*
* <p>
- * NOTE: This routing does not return Dao<T, ID> because of casting issues if we are assigning it to a custom DAO.
+ * NOTE: This routing does not return Dao<T, ID> because of casting issues if we are assigning it to a custom DAO.
* Grumble.
* </p>
*/
@@ -284,7 +284,7 @@ public abstract class OrmLiteSqliteOpenHelper extends SQLiteOpenHelper {
* Get a RuntimeExceptionDao for our class. This uses the {@link DaoManager} to cache the DAO for future gets.
*
* <p>
- * NOTE: This routing does not return RuntimeExceptionDao<T, ID> because of casting issues if we are assigning it to
+ * NOTE: This routing does not return RuntimeExceptionDao<T, ID> because of casting issues if we are assigning it to
* a custom DAO. Grumble.
* </p>
*/ | Fixed some javadocs issues. |
diff --git a/index.js b/index.js
index <HASH>..<HASH> 100644
--- a/index.js
+++ b/index.js
@@ -44,6 +44,7 @@ export default function extractAbbreviation(line, pos, lookAhead) {
let c;
const stream = new StreamReader(line);
+ stream.pos = pos;
const stack = [];
while (!stream.sol()) {
diff --git a/test/extract.js b/test/extract.js
index <HASH>..<HASH> 100644
--- a/test/extract.js
+++ b/test/extract.js
@@ -33,6 +33,7 @@ describe('Extract abbreviation', () => {
it('abbreviation with attributes', () => {
assert.deepEqual(extract('a foo[bar|]'), result('foo[bar]', 2));
assert.deepEqual(extract('a foo[bar="baz" a b]'), result('foo[bar="baz" a b]', 2));
+ assert.deepEqual(extract('foo bar[a|] baz'), result('bar[a]', 4));
});
it('tag test', () => { | 💩 Set proper initial stream reader position |
diff --git a/docker_squash/cli.py b/docker_squash/cli.py
index <HASH>..<HASH> 100644
--- a/docker_squash/cli.py
+++ b/docker_squash/cli.py
@@ -62,6 +62,7 @@ class CLI(object):
from_layer=args.from_layer, tag=args.tag, output_path=args.output_path, tmp_dir=args.tmp_dir, development=args.development).run()
except KeyboardInterrupt:
self.log.error("Program interrupted by user, exiting...")
+ sys.exit(1)
except:
e = sys.exc_info()[1] | added sys.exit(1) on KeyboardInterrupt |
diff --git a/source/rafcon/mvc/utils/constants.py b/source/rafcon/mvc/utils/constants.py
index <HASH>..<HASH> 100644
--- a/source/rafcon/mvc/utils/constants.py
+++ b/source/rafcon/mvc/utils/constants.py
@@ -28,7 +28,7 @@ CREATION_CURSOR = gtk.gdk.CROSS
MAX_VALUE_LABEL_TEXT_LENGTH = 7
-MINIMUM_SIZE_FOR_DISPLAY = 5
+MINIMUM_SIZE_FOR_DISPLAY = 2
GRID_SIZE = 10
BORDER_WIDTH_STATE_SIZE_FACTOR = 25. | Reduce limit under which elements are being hidden |
diff --git a/src/components/d-front-matter.js b/src/components/d-front-matter.js
index <HASH>..<HASH> 100644
--- a/src/components/d-front-matter.js
+++ b/src/components/d-front-matter.js
@@ -30,7 +30,6 @@ export function _moveLegacyAffiliationFormatIntoArray(frontMatter) {
author.affiliations = [newAffiliation];
}
}
- console.log(frontMatter)
return frontMatter
} | Remove stray console.log(frontmatter) call |
diff --git a/lib/module.js b/lib/module.js
index <HASH>..<HASH> 100644
--- a/lib/module.js
+++ b/lib/module.js
@@ -60,10 +60,11 @@ const report = _.curry(function(options, results) {
});
function makeLinter(options) {
- const parser = options.directories ? pathParsers.fullPathParser : pathParsers.fileNameParser;
+ const regexp = new RegExp('(' + options.extensionName + ')$');
+ const parser = options.extensions ? pathParsers.fileExtensionParser : (options.directories ? pathParsers.fullPathParser : pathParsers.fileNameParser);
return new Linter({
pathParser: parser,
- matcher: matchers[options.format]
+ matcher: options.extensions ? matchers.makeRegexStringTest(regexp) : matchers[options.format]
});
} | feat(file-extension-parser): added parsing condition |
diff --git a/spec/acceptance/simple_get_filter_spec.rb b/spec/acceptance/simple_get_filter_spec.rb
index <HASH>..<HASH> 100644
--- a/spec/acceptance/simple_get_filter_spec.rb
+++ b/spec/acceptance/simple_get_filter_spec.rb
@@ -18,7 +18,7 @@ RSpec.describe 'exercising simple_get_filter' do
end
context 'when using `get` to access a specific resource' do
- it 'returns resource' do
+ it '`puppet resource` uses `instances` and does the filtering' do
stdout_str, status = Open3.capture2e("puppet resource #{common_args} test_simple_get_filter foo")
expect(stdout_str.strip).to match %r{test_string\s*=>\s*'default'}
@@ -27,7 +27,7 @@ RSpec.describe 'exercising simple_get_filter' do
end
context 'when using `get` to remove a specific resource' do
- it 'receives names array' do
+ it 'the `retrieve` function does the lookup' do
stdout_str, status = Open3.capture2e("puppet resource #{common_args} test_simple_get_filter foo ensure=absent")
expect(stdout_str.strip).to match %r{undefined 'ensure' from 'present'} | Improve the wording of the tests to reflect what's happening |
diff --git a/src/client/components/MenuDropdownGrid/MenuDropdownGrid.react.js b/src/client/components/MenuDropdownGrid/MenuDropdownGrid.react.js
index <HASH>..<HASH> 100644
--- a/src/client/components/MenuDropdownGrid/MenuDropdownGrid.react.js
+++ b/src/client/components/MenuDropdownGrid/MenuDropdownGrid.react.js
@@ -2,6 +2,8 @@
/* eslint-disable no-script-url */
import React, { Component } from 'react';
import Types from 'prop-types';
+import chunk from 'lodash/chunk';
+import flatten from 'lodash/flatten';
import './MenuDropdownGrid.less';
import { SVG } from '@opuscapita/react-svg';
@@ -29,7 +31,12 @@ class MenuDropdownGrid extends Component {
items
} = this.props;
- const itemsElement = items.map((item, i) => {
+ // Hide row if all items in the row are disabled
+ const filteredItems = flatten(
+ chunk(items, ITEMS_PER_ROW).filter((itemsChunk) => itemsChunk.some(item => item.href))
+ );
+
+ const itemsElement = filteredItems.map((item, i) => {
if (!item) {
return (
<div | Hide row if all items in the row are disabled |
diff --git a/index.js b/index.js
index <HASH>..<HASH> 100644
--- a/index.js
+++ b/index.js
@@ -9,6 +9,7 @@ module.exports = ddescribeIit;
function ddescribeIit(opt) {
'use strict';
opt = opt || { allowDisabledTests: true, noColor: false };
+ // istanbul ignore next --- To many variables to cover in testing
var supports_colors = (function() {
if (opt.noColor) return false;
if (process.argv.indexOf('--no-color') !== -1) return false;
@@ -185,7 +186,7 @@ function ddescribeIit(opt) {
}
if (len === 1) x = '000' + x;
else if (len === 2) x = '00' + x;
- else if (len === 3) x = '0' + x;
+ // TODO(@caitp): Add support for > 8bit codepoints if ever needed
return x;
} | chore(ddescribe-iit): get that <I>% coverage report |
diff --git a/satpy/tests/test_readers.py b/satpy/tests/test_readers.py
index <HASH>..<HASH> 100644
--- a/satpy/tests/test_readers.py
+++ b/satpy/tests/test_readers.py
@@ -691,6 +691,7 @@ class TestYAMLFiles(unittest.TestCase):
reader_names = available_readers(yaml_loader=yaml.BaseLoader)
self.assertIn('abi_l1b', reader_names) # needs netcdf4
+ self.assertIn('viirs_l1b', reader_names)
self.assertEqual(len(reader_names), len(list(glob_config('readers/*.yaml')))) | refactor: add another reader name to check |
diff --git a/perfdump/models.py b/perfdump/models.py
index <HASH>..<HASH> 100644
--- a/perfdump/models.py
+++ b/perfdump/models.py
@@ -184,7 +184,10 @@ class BaseTimeModel(object):
"""
cur = cls.get_cursor()
- q = "SELECT file, SUM(elapsed) as sum_elapsed FROM {} ORDER BY sum_elapsed DESC LIMIT {}"
+ q = (
+ "SELECT file, SUM(elapsed) as sum_elapsed FROM {} GROUP BY file"
+ " ORDER BY sum_elapsed DESC LIMIT {}"
+ )
cur.execute(q.format(cls.meta['table'], num))
result = cur.fetchall()
# Don't return the weird invalid row if no tests were run
@@ -197,7 +200,6 @@ class BaseTimeModel(object):
"""Returns the total time taken across all results.
:rtype: float
-
"""
cur = cls.get_cursor()
q = "SELECT SUM(elapsed) FROM {}" | bug: Fix Query To Get Slowest Per-File Tests
* The query lacked a GROUP BY clause and so collapsed all the file names
down into a single one. |
diff --git a/PhpAmqpLib/Wire/GenericContent.php b/PhpAmqpLib/Wire/GenericContent.php
index <HASH>..<HASH> 100644
--- a/PhpAmqpLib/Wire/GenericContent.php
+++ b/PhpAmqpLib/Wire/GenericContent.php
@@ -9,7 +9,7 @@ use PhpAmqpLib\Channel\AMQPChannel;
*/
abstract class GenericContent
{
- /** @var string[] */
+ /** @var array */
public $delivery_info = array();
/** @var array Final property definitions */ | Update $delivery_info to simply an array |
diff --git a/src/Leevel/Database/Ddd/Entity.php b/src/Leevel/Database/Ddd/Entity.php
index <HASH>..<HASH> 100644
--- a/src/Leevel/Database/Ddd/Entity.php
+++ b/src/Leevel/Database/Ddd/Entity.php
@@ -786,9 +786,8 @@ abstract class Entity implements IArray, IJson, JsonSerializable, ArrayAccess
*/
public function withProp(string $prop, $value, bool $force = true, bool $ignoreReadonly = false, bool $ignoreUndefinedProp = false): self
{
- $prop = static::normalize($prop);
-
try {
+ $prop = static::normalize($prop);
$this->validate($prop);
} catch (InvalidArgumentException $e) {
if ($ignoreUndefinedProp) {
@@ -1115,7 +1114,7 @@ abstract class Entity implements IArray, IJson, JsonSerializable, ArrayAccess
}
/**
- * 获取主键.
+ * 获取主键值.
*
* - 唯一标识符.
* | refactor(ddd): code poem |
diff --git a/jupyterthemes/__init__.py b/jupyterthemes/__init__.py
index <HASH>..<HASH> 100644
--- a/jupyterthemes/__init__.py
+++ b/jupyterthemes/__init__.py
@@ -29,9 +29,9 @@ def install_path(profile=None, jupyter=True):
profile = profile or DEFAULT_PROFILE
home_path = os.path.expanduser(os.path.join(IPY_HOME))
profile_path = home_path.format(profile='profile_'+profile)
+ custom_path = '/'.join([profile_path, 'static', 'custom'])
if not os.path.exists(profile_path):
- custom_path = '/'.join([profile_path, 'static', 'custom'])
print "Profile %s does not exist at %s" % (profile, home_path)
print "creating profile: %s" % profile
subprocess.call(['ipython', 'profile', 'create', profile])
@@ -44,7 +44,7 @@ def install_path(profile=None, jupyter=True):
else:
print "No ipython config files (~/.ipython/profile_default/static/custom/)"
print "try again after running ipython, closing & refreshing your terminal session"
-
+
paths.append(custom_path)
if jupyter: | fix inf loop during install on ipython4 |
diff --git a/lib/orbacle/nesting_container.rb b/lib/orbacle/nesting_container.rb
index <HASH>..<HASH> 100644
--- a/lib/orbacle/nesting_container.rb
+++ b/lib/orbacle/nesting_container.rb
@@ -29,31 +29,31 @@ module Orbacle
end
def initialize
- @current_nesting = []
+ @levels = []
end
def get_output_nesting
- @current_nesting.map {|level| level.full_name }
+ @levels.map {|level| level.full_name }
end
def levels
- @current_nesting
+ @levels
end
def is_selfed?
- @current_nesting.last.is_a?(ClassConstLevel)
+ @levels.last.is_a?(ClassConstLevel)
end
def increase_nesting_const(const_ref)
- @current_nesting << ConstLevel.new(const_ref)
+ @levels << ConstLevel.new(const_ref)
end
def increase_nesting_self
- @current_nesting << ClassConstLevel.new(nesting_to_scope())
+ @levels << ClassConstLevel.new(nesting_to_scope())
end
def decrease_nesting
- @current_nesting.pop
+ @levels.pop
end
def scope_from_nesting_and_prename(prename) | Rename @current_nesting to @levels |
diff --git a/src/main/java/org/fxmisc/flowless/Navigator.java b/src/main/java/org/fxmisc/flowless/Navigator.java
index <HASH>..<HASH> 100644
--- a/src/main/java/org/fxmisc/flowless/Navigator.java
+++ b/src/main/java/org/fxmisc/flowless/Navigator.java
@@ -96,7 +96,10 @@ extends Region implements TargetPositionVisitor {
* and re-lays out the viewport
*/
public void scrollCurrentPositionBy(double delta) {
- targetPosition = currentPosition.scrollBy(delta);
+ // delta needs rounding otherwise thin lines appear between cells,
+ // notably when scrolling with a mouse or using a scroll bar and
+ // usually only visible when cells have dark backgrounds/borders.
+ targetPosition = currentPosition.scrollBy(Math.round(delta));
requestLayout();
} | Fix thin lines between cells (#<I>) |
diff --git a/cli/src/main/java/org/jboss/as/cli/operation/OperationRequestCompleter.java b/cli/src/main/java/org/jboss/as/cli/operation/OperationRequestCompleter.java
index <HASH>..<HASH> 100644
--- a/cli/src/main/java/org/jboss/as/cli/operation/OperationRequestCompleter.java
+++ b/cli/src/main/java/org/jboss/as/cli/operation/OperationRequestCompleter.java
@@ -118,7 +118,7 @@ public class OperationRequestCompleter implements Completor {
if(handler.hasOperationName() || handler.endsOnAddressOperationNameSeparator()) {
OperationCandidatesProvider provider = ctx.getOperationCandidatesProvider();
- final List<String> names = provider.getOperationNames(ctx.getPrefix());
+ final List<String> names = provider.getOperationNames(handler.getAddress());
if(names.isEmpty()) {
return -1;
} | pass the full address instead of just the prefix to the candidates provider
was: <I>d<I>be<I>e<I>a<I>d4f<I>f7aca<I>ca<I>fadd |
diff --git a/lightflow/models/dag.py b/lightflow/models/dag.py
index <HASH>..<HASH> 100644
--- a/lightflow/models/dag.py
+++ b/lightflow/models/dag.py
@@ -133,7 +133,7 @@ class Dag:
for task in nx.topological_sort(graph):
task.workflow_name = self.workflow_name
task.dag_name = self.name
- if len(graph.predecessors(task)) == 0:
+ if len(list(graph.predecessors(task))) == 0:
task.state = TaskState.Waiting
tasks.append(task)
@@ -166,7 +166,7 @@ class Dag:
if stopped:
task.state = TaskState.Stopped
else:
- pre_tasks = graph.predecessors(task)
+ pre_tasks = list(graph.predecessors(task))
if all([p.is_completed for p in pre_tasks]):
# check whether the task should be skipped
diff --git a/setup.py b/setup.py
index <HASH>..<HASH> 100644
--- a/setup.py
+++ b/setup.py
@@ -43,7 +43,7 @@ setup(
'celery>=4.0.2',
'click>=6.7',
'colorlog>=2.10.0',
- 'networkx>=1.11,<2',
+ 'networkx',
'pymongo>=3.6.0',
'pytz>=2016.10',
'redis>=2.10.5', | updated for networkx <I> (#<I>) |
diff --git a/plugins/org.eclipse.xtext/src/org/eclipse/xtext/resource/IGlobalServiceProvider.java b/plugins/org.eclipse.xtext/src/org/eclipse/xtext/resource/IGlobalServiceProvider.java
index <HASH>..<HASH> 100644
--- a/plugins/org.eclipse.xtext/src/org/eclipse/xtext/resource/IGlobalServiceProvider.java
+++ b/plugins/org.eclipse.xtext/src/org/eclipse/xtext/resource/IGlobalServiceProvider.java
@@ -10,6 +10,7 @@ package org.eclipse.xtext.resource;
import org.eclipse.emf.common.util.URI;
import org.eclipse.emf.ecore.EObject;
import org.eclipse.emf.ecore.InternalEObject;
+import org.eclipse.emf.ecore.resource.Resource;
import com.google.inject.ImplementedBy;
import com.google.inject.Inject;
@@ -56,8 +57,11 @@ public interface IGlobalServiceProvider {
if (eObject.eIsProxy()) {
return findService(((InternalEObject)eObject).eProxyURI(),serviceClazz);
} else {
- return findService(eObject.eResource().getURI(),serviceClazz);
+ Resource eResource = eObject.eResource();
+ if(eResource != null)
+ return findService(eResource.getURI(),serviceClazz);
}
+ return null;
}
} | [grammar][codeassist] Reworked feature proposals |
diff --git a/lib/tty/command.rb b/lib/tty/command.rb
index <HASH>..<HASH> 100644
--- a/lib/tty/command.rb
+++ b/lib/tty/command.rb
@@ -174,7 +174,7 @@ module TTY
# @api private
def command(*args)
cmd = Cmd.new(*args)
- cmd.update(@cmd_options)
+ cmd.update(**@cmd_options)
cmd
end | fix Ruby <I> warning: Using the last argument as keyword parameters is deprecated (#<I>) |
diff --git a/app/controllers/content_search_controller.rb b/app/controllers/content_search_controller.rb
index <HASH>..<HASH> 100644
--- a/app/controllers/content_search_controller.rb
+++ b/app/controllers/content_search_controller.rb
@@ -312,9 +312,16 @@ class ContentSearchController < ApplicationController
{:terms => {:enabled => [true]}}]
conditions << {:terms => {:product_id => product_ids}} unless product_ids.blank?
+ #get total repos
+ found = Repository.search(:load => true) do
+ query {string term, {:default_field => 'name'}} unless term.blank?
+ filter "and", conditions
+ size 1
+ end
Repository.search(:load => true) do
query {string term, {:default_field => 'name'}} unless term.blank?
filter "and", conditions
+ size found.total
end
end | <I> - fixing issue where only <I> repos would appear on content search |
diff --git a/bench/format/plot.py b/bench/format/plot.py
index <HASH>..<HASH> 100644
--- a/bench/format/plot.py
+++ b/bench/format/plot.py
@@ -145,7 +145,7 @@ class TimeSeriesCollection():
for val in self.data.iteritems():
stat_report = {}
stat_report['mean'] = stats.mean(map(lambda x: x, val[1]))
- stat_report['stddev'] = stats.stddev(map(lambda x: x, val[1]))
+ stat_report['stdev'] = stats.stdev(map(lambda x: x, val[1]))
res[val[0]] = stat_report
return res | stdev not stddev |
diff --git a/ph-oton-core/src/main/java/com/helger/photon/core/app/context/SimpleWebExecutionContext.java b/ph-oton-core/src/main/java/com/helger/photon/core/app/context/SimpleWebExecutionContext.java
index <HASH>..<HASH> 100644
--- a/ph-oton-core/src/main/java/com/helger/photon/core/app/context/SimpleWebExecutionContext.java
+++ b/ph-oton-core/src/main/java/com/helger/photon/core/app/context/SimpleWebExecutionContext.java
@@ -196,9 +196,9 @@ public class SimpleWebExecutionContext implements ISimpleWebExecutionContext
}
@Nonnull
- public Iterator <Map.Entry <String, Object>> getIterator ()
+ public Iterator <Map.Entry <String, Object>> iterator ()
{
- return m_aRequestScope.getIterator ();
+ return m_aRequestScope.iterator ();
}
public boolean getCheckBoxAttr (@Nullable final String sName, final boolean bDefaultValue) | Updated to new ph-commons API |
diff --git a/tests/Parsers/HslaParserTest.php b/tests/Parsers/HslaParserTest.php
index <HASH>..<HASH> 100644
--- a/tests/Parsers/HslaParserTest.php
+++ b/tests/Parsers/HslaParserTest.php
@@ -168,7 +168,7 @@ class HslaParserTest extends PHPUnit_Framework_TestCase
);
}
- public function test_it_throws_when_attempting_to_parse_unsopported_string()
+ public function test_it_throws_when_attempting_to_parse_unsupported_string()
{
$parser = new HslaParser; | Typo: unsopported => unsupported |
diff --git a/lib/prices.js b/lib/prices.js
index <HASH>..<HASH> 100644
--- a/lib/prices.js
+++ b/lib/prices.js
@@ -111,7 +111,7 @@ Prices.prototype.getValues = function(opts, callback) {
}
for (var j=0; j<row.Columns.length; j++) {
var column = row.Columns[j]
- var value = parseFloat(column.Value.replace(/(?:\s|,)/, '.'))
+ var value = parseFloat(column.Value.replace(/[. ]+/g, ''))
if (isNaN(value)) {
// console.log('invalid value ' + column.Value)
continue | Update prices.js
Regex failed in the last commit. |
diff --git a/trie/dtrie/dtrie_test.go b/trie/dtrie/dtrie_test.go
index <HASH>..<HASH> 100644
--- a/trie/dtrie/dtrie_test.go
+++ b/trie/dtrie/dtrie_test.go
@@ -155,7 +155,7 @@ func TestIterate(t *testing.T) {
for atomic.LoadInt64(&c) < 100 {
}
close(stop)
- assert.True(t, c > 99 && c < 110)
+ assert.True(t, c > 99 && c < 1000)
// test with collisions
n = insertTest(t, collisionHash, 1000)
c = 0 | widen bounds for atomic assertion |
diff --git a/lib/suites/LinkedDataSignature.js b/lib/suites/LinkedDataSignature.js
index <HASH>..<HASH> 100644
--- a/lib/suites/LinkedDataSignature.js
+++ b/lib/suites/LinkedDataSignature.js
@@ -55,13 +55,11 @@ module.exports = class LinkedDataSignature extends LinkedDataProof {
// build proof (currently known as `signature options` in spec)
let proof;
if(this.proof) {
- // use proof JSON-LD document passed to API
- proof = await jsonld.compact(
- this.proof, constants.SECURITY_CONTEXT_URL,
- {documentLoader, expansionMap, compactToRelative: false});
+ // shallow copy
+ proof = {...this.proof};
} else {
// create proof JSON-LD document
- proof = {'@context': constants.SECURITY_CONTEXT_URL};
+ proof = {};
}
// ensure proof type is set | Do not insert security context into proof. |
diff --git a/ribbon-core/src/main/java/com/netflix/client/AbstractLoadBalancerAwareClient.java b/ribbon-core/src/main/java/com/netflix/client/AbstractLoadBalancerAwareClient.java
index <HASH>..<HASH> 100644
--- a/ribbon-core/src/main/java/com/netflix/client/AbstractLoadBalancerAwareClient.java
+++ b/ribbon-core/src/main/java/com/netflix/client/AbstractLoadBalancerAwareClient.java
@@ -192,6 +192,9 @@ public abstract class AbstractLoadBalancerAwareClient<S extends ClientRequest, T
response = execute(request);
done = true;
} catch (Exception e) {
+ if (serverStats != null) {
+ serverStats.addToFailureCount();
+ }
lastException = e;
if (isCircuitBreakerException(e) && serverStats != null) {
serverStats.incrementSuccessiveConnectionFailureCount(); | Track total failures count for client upon exception. |
diff --git a/src/Psalm/Internal/PropertyMap.php b/src/Psalm/Internal/PropertyMap.php
index <HASH>..<HASH> 100644
--- a/src/Psalm/Internal/PropertyMap.php
+++ b/src/Psalm/Internal/PropertyMap.php
@@ -327,7 +327,7 @@ return [
'previousSibling' => 'DOMNode|null',
'nextSibling' => 'DOMNode|null',
'attributes' => 'null',
- 'ownerDocument' => 'DOMDocument',
+ 'ownerDocument' => 'DOMDocument|null',
'namespaceURI' => 'string|null',
'prefix' => 'string',
'localName' => 'string', | Fix #<I> - use correct property type for ownerDocument |
diff --git a/plugins/CoreHome/angularjs/common/services/periods.js b/plugins/CoreHome/angularjs/common/services/periods.js
index <HASH>..<HASH> 100644
--- a/plugins/CoreHome/angularjs/common/services/periods.js
+++ b/plugins/CoreHome/angularjs/common/services/periods.js
@@ -346,7 +346,7 @@
date.setTime(date.getTime() + date.getTimezoneOffset() * 60 * 1000);
// apply piwik site timezone (if it exists)
- date.setHours((piwik.timezoneOffset || 0) / 3600);
+ date.setHours(date.getHours() + ((piwik.timezoneOffset || 0) / 3600));
// get rid of hours/minutes/seconds/etc.
date.setHours(0); | Add timezone to current date hours instead of directly setting to timezone offset. (#<I>) |
diff --git a/railties/lib/rails/application.rb b/railties/lib/rails/application.rb
index <HASH>..<HASH> 100644
--- a/railties/lib/rails/application.rb
+++ b/railties/lib/rails/application.rb
@@ -149,7 +149,10 @@ module Rails
require "action_dispatch/http/rack_cache" if rack_cache
middleware.use ::Rack::Cache, rack_cache if rack_cache
- middleware.use ::ActionDispatch::Static, config.static_asset_paths if config.serve_static_assets
+ if config.serve_static_assets
+ asset_paths = ActiveSupport::OrderedHash[config.static_asset_paths.to_a.reverse]
+ middleware.use ::ActionDispatch::Static, asset_paths
+ end
middleware.use ::Rack::Lock unless config.allow_concurrency
middleware.use ::Rack::Runtime
middleware.use ::Rails::Rack::Logger | Application's assets should have higher priority than engine's ones
[#<I> state:resolved] |
diff --git a/setup.py b/setup.py
index <HASH>..<HASH> 100755
--- a/setup.py
+++ b/setup.py
@@ -68,8 +68,23 @@ def _stamp_version(filename):
print("WARNING: Couldn't find version line in file %s" % filename, file=sys.stderr)
install_requires = ['gitdb >= 0.6.4']
-if sys.version_info[:2] < (2, 7):
- install_requires.append('ordereddict')
+extras_require = {
+ ':python_version == "2.6"': ['ordereddict'],
+}
+
+try:
+ if 'bdist_wheel' not in sys.argv:
+ for key, value in extras_require.items():
+ if key.startswith(':') and pkg_resources.evaluate_marker(key[1:]):
+ install_requires.extend(value)
+except Exception:
+ logging.getLogger(__name__).exception(
+ 'Something went wrong calculating platform specific dependencies, so '
+ "you're getting them all!"
+ )
+ for key, value in extras_require.items():
+ if key.startswith(':'):
+ install_requires.extend(value)
# end
setup( | install ordereddict only on <I> with wheel |
diff --git a/yubico_client/yubico.py b/yubico_client/yubico.py
index <HASH>..<HASH> 100644
--- a/yubico_client/yubico.py
+++ b/yubico_client/yubico.py
@@ -82,7 +82,7 @@ class Yubico(object):
' argument'))
self.client_id = client_id
- self.key = base64.b64decode(key) if key is not None else None
+ self.key = base64.b64decode(key.encode('ascii')) if key is not None else None
self.verify_cert = verify_cert
self.translate_otp = translate_otp
self.api_urls = self._init_request_urls(api_urls=api_urls) | yubico.py: Convert key to byte string before passing it to b<I>decode
In Python3 <= <I>, the base<I>.b<I>decode function only accepts byte strings, so
we need to convert the key to one. |
diff --git a/tensorboard/java/org/tensorflow/tensorboard/vulcanize/Vulcanize.java b/tensorboard/java/org/tensorflow/tensorboard/vulcanize/Vulcanize.java
index <HASH>..<HASH> 100644
--- a/tensorboard/java/org/tensorflow/tensorboard/vulcanize/Vulcanize.java
+++ b/tensorboard/java/org/tensorflow/tensorboard/vulcanize/Vulcanize.java
@@ -187,6 +187,9 @@ public final class Vulcanize {
createFile(
jsOutput, shouldExtractJs ? extractAndTransformJavaScript(document, jsPath) : "");
Document normalizedDocument = getFlattenedHTML5Document(document);
+ // Prevent from correcting the DOM structure and messing up the whitespace
+ // in the template.
+ normalizedDocument.outputSettings().prettyPrint(false);
createFile(output, normalizedDocument.toString());
} | vulc: fix pretty print messing up whitespace (#<I>)
Our data location in the runs selector use tf-wbr-string which is
roughly written as `<template>[[prop]]<wbr></template>`. With the pretty
print, this was rewritten as
```
<template>
[[prop]]
<wbr>
</template>
```
which has whitespace and make the browser render the whitespace.
This change fixes the issue by turning off the pretty print. |
diff --git a/packages/@vue/cli-service/lib/config/base.js b/packages/@vue/cli-service/lib/config/base.js
index <HASH>..<HASH> 100644
--- a/packages/@vue/cli-service/lib/config/base.js
+++ b/packages/@vue/cli-service/lib/config/base.js
@@ -33,7 +33,7 @@ module.exports = (api, options) => {
.end()
.output
.path(api.resolve(options.outputDir))
- .filename(isLegacyBundle ? '[name]-legacy.js' : '[name].js')
+ .filename(isLegacyBundle ? '[name]-legacy.[hash:8].js' : '[name].[hash:8].js')
.publicPath(options.baseUrl)
webpackConfig.resolve | fix: add hash to filename in development mode (#<I>)
to circumvent a Safari caching issue
closes #<I>, #<I> |
diff --git a/tests/StringCalcTests.php b/tests/StringCalcTests.php
index <HASH>..<HASH> 100644
--- a/tests/StringCalcTests.php
+++ b/tests/StringCalcTests.php
@@ -79,7 +79,6 @@ class StringCalcTest extends \PHPUnit\Framework\TestCase
['floor(2.8)', 2],
['fMod(2.2,2.1)', 0.1],
['hypot(2,2)', 2.8284271247462],
- ['intdiv(11,5)', 2],
['log(2)', 0.69314718055995],
['log(2,2)', 1],
['logOneP(2)', 1.0986122886681], | Removed intdiv from the tests |
diff --git a/Symfony/CS/Tokenizer/Tokens.php b/Symfony/CS/Tokenizer/Tokens.php
index <HASH>..<HASH> 100644
--- a/Symfony/CS/Tokenizer/Tokens.php
+++ b/Symfony/CS/Tokenizer/Tokens.php
@@ -19,6 +19,8 @@ use Symfony\CS\Utils;
*
* @author Dariusz Rumiński <dariusz.ruminski@gmail.com>
* @author Gregor Harlan <gharlan@web.de>
+ *
+ * @method Token current()
*/
class Tokens extends \SplFixedArray
{ | Tokens: added typehint for Iterator elements |
diff --git a/lib/conversion_store.go b/lib/conversion_store.go
index <HASH>..<HASH> 100644
--- a/lib/conversion_store.go
+++ b/lib/conversion_store.go
@@ -45,6 +45,7 @@ func (ms *ConversionStore) WriteACI(path string) (string, error) {
if err != nil {
return "", err
}
+ defer cr.Close()
h := sha512.New()
r := io.TeeReader(cr, h)
@@ -97,6 +98,7 @@ func (ms *ConversionStore) ReadStream(key string) (io.ReadCloser, error) {
if err != nil {
return nil, err
}
+ defer tr.Close()
return ioutil.NopCloser(tr), nil
} | lib: close aci.NewCompressedReader
The interface for aci.NewCompressedReader changed in appc to return a
ReadCloser so we're resposible for closing it. |
diff --git a/chrome.js b/chrome.js
index <HASH>..<HASH> 100644
--- a/chrome.js
+++ b/chrome.js
@@ -19,6 +19,10 @@ module.exports = function(opts) {
return callback(err);
}
+ if (! sourceId) {
+ return callback(new Error('user rejected screen share request'));
+ }
+
// pass the constraints through
return callback(null, {
audio: false, | Report user rejection of screenshare as an error |
diff --git a/src/main/java/org/jamesframework/core/problems/solutions/SubsetSolution.java b/src/main/java/org/jamesframework/core/problems/solutions/SubsetSolution.java
index <HASH>..<HASH> 100644
--- a/src/main/java/org/jamesframework/core/problems/solutions/SubsetSolution.java
+++ b/src/main/java/org/jamesframework/core/problems/solutions/SubsetSolution.java
@@ -268,16 +268,21 @@ public class SubsetSolution extends Solution {
return hash;
}
+ /**
+ * Creates a nicely formatted, human readable string containing the selected IDs.
+ *
+ * @return formatted string
+ */
@Override
public String toString(){
StringBuilder str = new StringBuilder();
str.append("SubsetSolution: {");
- // add selected IDs
- for(int ID : selected){
- str.append(ID).append(", ");
- }
- // remove final comma and space if nonzero number of selected IDs
+ // add selected IDs, if any
if(getNumSelectedIDs() > 0){
+ for(int ID : selected){
+ str.append(ID).append(", ");
+ }
+ // remove final comma and space
str.delete(str.length()-2, str.length());
}
// close brackets | updated toString of subset solution |
diff --git a/autofit/non_linear/settings.py b/autofit/non_linear/settings.py
index <HASH>..<HASH> 100644
--- a/autofit/non_linear/settings.py
+++ b/autofit/non_linear/settings.py
@@ -55,5 +55,14 @@ class SettingsSearch:
}
@property
+ def search_dict_x1_core(self):
+ return {
+ "path_prefix": self.path_prefix,
+ "unique_tag": self.unique_tag,
+ "number_of_cores": 1,
+ "session": self.session,
+ }
+
+ @property
def fit_dict(self):
return {"info": self.info, "pickle_files": self.pickle_files}
\ No newline at end of file | updated Settings object for x1 core |
diff --git a/EventListener/BugsnagListener.php b/EventListener/BugsnagListener.php
index <HASH>..<HASH> 100644
--- a/EventListener/BugsnagListener.php
+++ b/EventListener/BugsnagListener.php
@@ -84,7 +84,8 @@ class BugsnagListener implements EventSubscriberInterface
}
/**
- * Handle a console exception.
+ * Handle a console exception (used instead of ConsoleErrorEvent before
+ * Symfony 3.3 and kept for backwards compatibility).
*
* @param \Symfony\Component\Console\Event\ConsoleExceptionEvent $event
*
diff --git a/Tests/Listener/BugsnagListenerTest.php b/Tests/Listener/BugsnagListenerTest.php
index <HASH>..<HASH> 100644
--- a/Tests/Listener/BugsnagListenerTest.php
+++ b/Tests/Listener/BugsnagListenerTest.php
@@ -52,9 +52,6 @@ class BugsnagListenerTest extends TestCase
$listener->onKernelException($event);
}
- /**
- * @requires class foo
- */
public function testOnConsoleError()
{
if (!class_exists('Symfony\Component\Console\Event\ConsoleErrorEvent')) { | style: phpdoc changes following review |
diff --git a/openquake/risklib/workflows.py b/openquake/risklib/workflows.py
index <HASH>..<HASH> 100644
--- a/openquake/risklib/workflows.py
+++ b/openquake/risklib/workflows.py
@@ -498,7 +498,7 @@ class ProbabilisticEventBased(Workflow):
self.insured_losses = insured_losses
self.return_loss_matrix = True
self.loss_ratios = loss_ratios
- self.time_ratio = risk_investigation_time / (
+ self.time_ratio = time_span / (
investigation_time * ses_per_logic_tree_path)
def event_loss(self, loss_matrix, event_ids): | Fixed the case of risk_investigation_time None |
diff --git a/gns3server/version.py b/gns3server/version.py
index <HASH>..<HASH> 100644
--- a/gns3server/version.py
+++ b/gns3server/version.py
@@ -23,7 +23,7 @@
# or negative for a release candidate or beta (after the base version
# number has been incremented)
-__version__ = "2.1.0b2"
+__version__ = "2.1.0dev5"
__version_info__ = (2, 1, 0, -99)
# If it's a git checkout try to add the commit
if "dev" in __version__: | Back to development on <I>dev5 |
diff --git a/byte-buddy-dep/src/main/java/net/bytebuddy/dynamic/scaffold/TypeWriter.java b/byte-buddy-dep/src/main/java/net/bytebuddy/dynamic/scaffold/TypeWriter.java
index <HASH>..<HASH> 100644
--- a/byte-buddy-dep/src/main/java/net/bytebuddy/dynamic/scaffold/TypeWriter.java
+++ b/byte-buddy-dep/src/main/java/net/bytebuddy/dynamic/scaffold/TypeWriter.java
@@ -2452,7 +2452,9 @@ public interface TypeWriter<T> {
@Override
public int getModifiers() {
- return Opcodes.ACC_STATIC | Opcodes.ACC_PRIVATE | Opcodes.ACC_SYNTHETIC;
+ return Opcodes.ACC_SYNTHETIC | Opcodes.ACC_STATIC | (instrumentedType.isClassType()
+ ? Opcodes.ACC_PRIVATE
+ : Opcodes.ACC_PUBLIC);
}
@Override | Set rebased class initializer method to be public if the class initializer is defined on an interface type. |
diff --git a/src/frontend/org/voltcore/zk/SynchronizedStatesManager.java b/src/frontend/org/voltcore/zk/SynchronizedStatesManager.java
index <HASH>..<HASH> 100644
--- a/src/frontend/org/voltcore/zk/SynchronizedStatesManager.java
+++ b/src/frontend/org/voltcore/zk/SynchronizedStatesManager.java
@@ -1121,7 +1121,7 @@ public class SynchronizedStatesManager {
"Unexpected failure in StateMachine.", true, e);
membersWithResults = new TreeSet<String>();
}
- if (Sets.symmetricDifference(m_knownMembers, membersWithResults).isEmpty()) {
+ if (Sets.difference(m_knownMembers, membersWithResults).isEmpty()) {
processResultQuorum(membersWithResults);
assert(!debugIsLocalStateLocked());
} | ENG-<I>:
Don't use SymmetricDifference to compare results with active because a result could be supplied by a node that died (and is not in the member list). |
diff --git a/lib/jsonapi/resource_serializer.rb b/lib/jsonapi/resource_serializer.rb
index <HASH>..<HASH> 100644
--- a/lib/jsonapi/resource_serializer.rb
+++ b/lib/jsonapi/resource_serializer.rb
@@ -230,7 +230,7 @@ module JSONAPI
end
def custom_generation_options
- {
+ @_custom_generation_options ||= {
serializer: self,
serialization_options: @serialization_options
} | Cache custom_generation_options options
This hash only needs to be computed once, and repeatedly building it
results in a lot of memory allocations. |
diff --git a/spec/spec_helper.rb b/spec/spec_helper.rb
index <HASH>..<HASH> 100644
--- a/spec/spec_helper.rb
+++ b/spec/spec_helper.rb
@@ -5,7 +5,7 @@ if ENV['CI'] || ENV['GENERATE_COVERAGE']
require 'simplecov'
require 'coveralls'
- if ENV['CI']
+ if ENV['CI'] || ENV['TRAVIS']
SimpleCov.formatter = Coveralls::SimpleCov::Formatter
elsif ENV['GENERATE_COVERAGE']
SimpleCov.formatter = SimpleCov::Formatter::HTMLFormatter | [Specs] Apparently the CI flag is not set on the mac workers |
diff --git a/dev.py b/dev.py
index <HASH>..<HASH> 100755
--- a/dev.py
+++ b/dev.py
@@ -123,6 +123,10 @@ def test(suites):
warnings.filterwarnings(action='ignore', category=DeprecationWarning, module='webtest.*',
message=msg3)
+ # Selenium tests client side code, so we only test on the newest Python version
+ if sys.version_info[0:2] != (3, 7):
+ os.environ.setdefault('SKIP_SELENIUM_TESTS', 'y')
+
work_dir = os.path.join(_rootdir, 'ca')
os.chdir(work_dir) | default to skip selenium tests everywhere but py<I> |
diff --git a/core/Plugin/Manager.php b/core/Plugin/Manager.php
index <HASH>..<HASH> 100644
--- a/core/Plugin/Manager.php
+++ b/core/Plugin/Manager.php
@@ -447,7 +447,7 @@ class Manager
return self::$pluginsToPathCache[$pluginName];
}
- $corePluginsDir = PIWIK_INCLUDE_PATH . 'plugins/' . $pluginName;
+ $corePluginsDir = PIWIK_INCLUDE_PATH . '/plugins/' . $pluginName;
if (is_dir($corePluginsDir)) {
// for faster performance
self::$pluginsToPathCache[$pluginName] = self::getPluginRealPath($corePluginsDir); | Adds missing / in directoy check (#<I>) |
diff --git a/edisgo/io/electromobility_import.py b/edisgo/io/electromobility_import.py
index <HASH>..<HASH> 100644
--- a/edisgo/io/electromobility_import.py
+++ b/edisgo/io/electromobility_import.py
@@ -7,13 +7,15 @@ import os
from pathlib import Path, PurePath
from typing import TYPE_CHECKING
-import geopandas as gpd
import numpy as np
import pandas as pd
from numpy.random import default_rng
from sklearn import preprocessing
+if "READTHEDOCS" not in os.environ:
+ import geopandas as gpd
+
if TYPE_CHECKING:
from edisgo import EDisGo | moving geopandas import out of RtD |
diff --git a/tests/test_current_charts.py b/tests/test_current_charts.py
index <HASH>..<HASH> 100644
--- a/tests/test_current_charts.py
+++ b/tests/test_current_charts.py
@@ -79,8 +79,8 @@ class TestCurrentGreatestHot100Singles(Base, unittest.TestCase):
skipPeakPosCheck=True
)
for entry in self.chart:
- self.assertIsNone(entry.peakPos)
- self.assertEqual(entry.lastPos, entry.rank)
+ self.assertEqual(entry.peakPos, entry.rank)
+ self.assertEqual(entry.lastPos, 0)
self.assertEqual(entry.weeks, 1) # This is kind of unintuitive... | Fix test (for greatest-hot-<I>-singles) |
diff --git a/CHANGES.rst b/CHANGES.rst
index <HASH>..<HASH> 100644
--- a/CHANGES.rst
+++ b/CHANGES.rst
@@ -1,3 +1,10 @@
+Version 0.0.13
+--------------
+
+* Fixed an error in :class:`.oauth2.Google` when the access token request
+ resulted in an
+ ``OAuth 2 parameters can only have a single value: client_secret`` error.
+
Version 0.0.12
--------------
diff --git a/doc/source/conf.py b/doc/source/conf.py
index <HASH>..<HASH> 100644
--- a/doc/source/conf.py
+++ b/doc/source/conf.py
@@ -124,7 +124,7 @@ copyright = u'2013, Peter Hudec'
# built documents.
#
# The short X.Y version.
-version = '0.0.10'
+version = '0.0.13'
# The full version, including alpha/beta/rc tags.
release = version
diff --git a/setup.py b/setup.py
index <HASH>..<HASH> 100644
--- a/setup.py
+++ b/setup.py
@@ -5,7 +5,7 @@ from authomatic import six
setup(
name='Authomatic',
- version='0.0.12', # TODO: Put version in one place.
+ version='0.0.13', # TODO: Put version in one place.
packages=find_packages(),
package_data={'': ['*.txt', '*.rst']},
author='Peter Hudec', | Updated release version to <I>. |
diff --git a/server.go b/server.go
index <HASH>..<HASH> 100644
--- a/server.go
+++ b/server.go
@@ -70,7 +70,7 @@ func (s *Server) Run() error {
// Send sends a message throught the connection denoted by the connection ID.
func (s *Server) Send(connID string, msg []byte) error {
- if conn, ok := s.conns.Get(connID); ok {
+ if conn, ok := s.conns.GetOk(connID); ok {
return conn.(*Conn).Write(msg)
} | adapt to change in cmap lib |
diff --git a/lib/plugins/filter/template_locals/i18n.js b/lib/plugins/filter/template_locals/i18n.js
index <HASH>..<HASH> 100644
--- a/lib/plugins/filter/template_locals/i18n.js
+++ b/lib/plugins/filter/template_locals/i18n.js
@@ -22,10 +22,9 @@ function i18nLocalsFilter(locals) {
// i18n.languages is always an array with at least one argument ('default')
lang = i18nConfigLanguages[0];
}
-
- page.lang = lang;
}
+ page.lang = lang;
page.canonical_path = page.canonical_path || locals.path;
const languages = [...new Set([].concat(lang, i18nConfigLanguages, i18nLanguages).filter(Boolean))]; | fix(i<I>n): page.lang is undefined when using the key `language` in front-matter (#<I>) |
diff --git a/texture.js b/texture.js
index <HASH>..<HASH> 100644
--- a/texture.js
+++ b/texture.js
@@ -155,7 +155,7 @@ Object.defineProperties(proto, {
var psamples = this._anisoSamples
this._anisoSamples = Math.max(i, 1)|0
if(psamples !== this._anisoSamples) {
- var ext = gl.getExtension('EXT_texture_filter_anisotropic')
+ var ext = this.gl.getExtension('EXT_texture_filter_anisotropic')
if(ext) {
this.gl.texParameterf(this.gl.TEXTURE_2D, ext.TEXTURE_MAX_ANISOTROPY_EXT, this._anisoSamples)
} | Fix crash in mipSamples setter |
diff --git a/src/ol/control/attributioncontrol.js b/src/ol/control/attributioncontrol.js
index <HASH>..<HASH> 100644
--- a/src/ol/control/attributioncontrol.js
+++ b/src/ol/control/attributioncontrol.js
@@ -99,13 +99,6 @@ ol.control.Attribution = function(opt_options) {
goog.events.listen(button, goog.events.EventType.CLICK,
this.handleClick_, false, this);
- goog.events.listen(button, [
- goog.events.EventType.MOUSEOUT,
- goog.events.EventType.FOCUSOUT
- ], function() {
- this.blur();
- }, false);
-
var cssClasses = className + ' ' + ol.css.CLASS_UNSELECTABLE + ' ' +
ol.css.CLASS_CONTROL +
(this.collapsed_ && this.collapsible_ ? ' ol-collapsed' : '') + | Remove blur workaround in ol.control.Attribution
leftover from #<I> |
diff --git a/mod/quiz/report/responses/responses_table.php b/mod/quiz/report/responses/responses_table.php
index <HASH>..<HASH> 100644
--- a/mod/quiz/report/responses/responses_table.php
+++ b/mod/quiz/report/responses/responses_table.php
@@ -46,15 +46,14 @@ class quiz_report_responses_table extends table_sql {
if (!$this->is_downloading()) {
// Print "Select all" etc.
if ($this->candelete) {
- echo '<table id="commands">';
- echo '<tr><td>';
+ echo '<div id="commands">';
echo '<a href="javascript:select_all_in(\'DIV\',null,\'tablecontainer\');">'.
get_string('selectall', 'quiz').'</a> / ';
echo '<a href="javascript:deselect_all_in(\'DIV\',null,\'tablecontainer\');">'.
get_string('selectnone', 'quiz').'</a> ';
echo ' ';
echo '<input type="submit" value="'.get_string('deleteselected', 'quiz_overview').'"/>';
- echo '</td></tr></table>';
+ echo '</div>';
// Close form
echo '</div>';
echo '</form></div>'; | MDL-<I> "move detailled responses report out of contrib into main distribution" minor fix to html to align select all / deselect all with table |
diff --git a/sfm-datastax/src/main/java/org/sfm/datastax/impl/RowGetterFactory.java b/sfm-datastax/src/main/java/org/sfm/datastax/impl/RowGetterFactory.java
index <HASH>..<HASH> 100644
--- a/sfm-datastax/src/main/java/org/sfm/datastax/impl/RowGetterFactory.java
+++ b/sfm-datastax/src/main/java/org/sfm/datastax/impl/RowGetterFactory.java
@@ -21,11 +21,11 @@ import java.net.InetAddress;
import org.sfm.tuples.Tuple2;
import org.sfm.tuples.Tuples;
-//IFJAVA8_START
-import org.sfm.map.getter.time.JavaTimeGetterFactory;
import org.sfm.utils.conv.Converter;
import org.sfm.utils.conv.ConverterFactory;
+//IFJAVA8_START
+import org.sfm.map.getter.time.JavaTimeGetterFactory;
import java.time.*;
//IFJAVA8_END
import java.util.*; | #<I> add support for set and list type conversion |
diff --git a/vraptor-core/src/main/java/br/com/caelum/vraptor/validator/I18nParam.java b/vraptor-core/src/main/java/br/com/caelum/vraptor/validator/I18nParam.java
index <HASH>..<HASH> 100644
--- a/vraptor-core/src/main/java/br/com/caelum/vraptor/validator/I18nParam.java
+++ b/vraptor-core/src/main/java/br/com/caelum/vraptor/validator/I18nParam.java
@@ -16,6 +16,7 @@
package br.com.caelum.vraptor.validator;
import java.io.Serializable;
+import java.util.Objects;
import java.util.ResourceBundle;
import javax.enterprise.inject.Vetoed;
@@ -48,4 +49,18 @@ public class I18nParam implements Serializable {
public String toString() {
return String.format("i18n(%s)", key);
}
-}
+
+ @Override
+ public int hashCode() {
+ return Objects.hashCode(key);
+ }
+
+ @Override
+ public boolean equals(Object obj) {
+ if (this == obj) return true;
+ if (obj == null) return false;
+ if (getClass() != obj.getClass()) return false;
+ I18nParam other = (I18nParam) obj;
+ return Objects.equals(key, other.key);
+ }
+}
\ No newline at end of file | implementing equals and hashcode on i<I>nparam |
diff --git a/node-persist.js b/node-persist.js
index <HASH>..<HASH> 100644
--- a/node-persist.js
+++ b/node-persist.js
@@ -301,7 +301,7 @@ var parseString = function(str){
if(options.logging){
console.log("parse error: ", e);
}
- return {};
+ return undefined;
}
};
@@ -315,4 +315,4 @@ var parseFile = function (key) {
console.log("loaded: " + key);
}
});
-};
\ No newline at end of file
+}; | if a string cannot be parsed, it seems more accurate to return undefined rather than an empty object |
diff --git a/Neos.Eel/Classes/FlowQuery/Operations/Object/FilterOperation.php b/Neos.Eel/Classes/FlowQuery/Operations/Object/FilterOperation.php
index <HASH>..<HASH> 100644
--- a/Neos.Eel/Classes/FlowQuery/Operations/Object/FilterOperation.php
+++ b/Neos.Eel/Classes/FlowQuery/Operations/Object/FilterOperation.php
@@ -234,7 +234,7 @@ class FilterOperation extends AbstractOperation
case '=':
return $value === $operand;
case '=~':
- return strcasecmp($value, $operand) == 0;
+ return strcasecmp($value, $operand) === 0;
case '!=':
return $value !== $operand;
case '!=~': | Update Neos.Eel/Classes/FlowQuery/Operations/Object/FilterOperation.php |
diff --git a/src/app/Http/Controllers/Options.php b/src/app/Http/Controllers/Options.php
index <HASH>..<HASH> 100644
--- a/src/app/Http/Controllers/Options.php
+++ b/src/app/Http/Controllers/Options.php
@@ -12,5 +12,5 @@ class Options extends Controller
protected $model = Person::class;
- protected $queryAttributes = ['name', 'appellative', 'uid'];
+ protected $queryAttributes = ['name', 'appellative', 'uid', 'phone'];
} | adds phone to query attributes in Options.php |
diff --git a/tests/FluentDOMTest.php b/tests/FluentDOMTest.php
index <HASH>..<HASH> 100644
--- a/tests/FluentDOMTest.php
+++ b/tests/FluentDOMTest.php
@@ -338,10 +338,9 @@ class FluentDOMTest extends FluentDomTestCase {
* @group CoreFunctions
*/
function testItem() {
- $doc = FluentDOM(self::XML);
- $doc = $doc->find('/items');
- $this->assertEquals($doc->document->documentElement, $doc->item(0));
- $this->assertEquals(NULL, $doc->item(-10));
+ $fd = $this->getFixtureFromString(self::XML)->find('/items');
+ $this->assertEquals($fd->document->documentElement, $fd->item(0));
+ $this->assertEquals(NULL, $fd->item(-10));
}
/** | FluentDOMTest:
- changed: refactoring item() method test (use mock objects, cleanup) |
diff --git a/Kwf/Assets/Dependency/File/Css.php b/Kwf/Assets/Dependency/File/Css.php
index <HASH>..<HASH> 100644
--- a/Kwf/Assets/Dependency/File/Css.php
+++ b/Kwf/Assets/Dependency/File/Css.php
@@ -24,6 +24,10 @@ class Kwf_Assets_Dependency_File_Css extends Kwf_Assets_Dependency_File
$cfg = new Zend_Config_Ini('assetVariables.ini', $section);
$assetVariables[$section] = array_merge($assetVariables[$section], $cfg->toArray());
}
+ foreach ($assetVariables[$section] as $k=>$i) {
+ //also support lowercase variables
+ if (strtolower($k) != $k) $assetVariables[$section][strtolower($k)] = $i;
+ }
}
foreach ($assetVariables[$section] as $k=>$i) {
$contents = preg_replace('#\\$'.preg_quote($k).'([^a-z0-9A-Z])#', "$i\\1", $contents); //deprecated syntax | fix assetVariables with uppercase letters in scss files
sass lowercases everything so the variables wheren't found anymore |
diff --git a/corenlp_pywrap/pywrap.py b/corenlp_pywrap/pywrap.py
index <HASH>..<HASH> 100644
--- a/corenlp_pywrap/pywrap.py
+++ b/corenlp_pywrap/pywrap.py
@@ -125,6 +125,11 @@ class CoreNLP:
index = new_index
tokens = sentence['tokens']
for val in tokens:
+
+ #workaround to handle length inconsistancie with normalizedNER, rethink the logic
+ if 'ner' in val.values() and 'normalizedNER' not in val.values():
+ token_dict['normalizedNER'].append('')
+
for key, val in val.items():
if key == 'index':
new_index = index + int(val) | inconsistency with normalizedNER |
diff --git a/lib/model/user.js b/lib/model/user.js
index <HASH>..<HASH> 100644
--- a/lib/model/user.js
+++ b/lib/model/user.js
@@ -227,7 +227,7 @@ User.prototype.follow = function(id, callback) {
// XXX: Remote follow
callback(null);
} else {
- Stream.get(other.nickname + ":followers", this);
+ Stream.get("user:" + other.nickname + ":followers", this);
}
},
function(err, stream) {
@@ -272,7 +272,7 @@ User.prototype.stopFollowing = function(id, callback) {
// XXX: Remote follow
callback(null);
} else {
- Stream.get(other.nickname + ":followers", this);
+ Stream.get("user:" + other.nickname + ":followers", this);
}
},
function(err, stream) { | Prefix other streams with "user:" too |
diff --git a/src/index.js b/src/index.js
index <HASH>..<HASH> 100644
--- a/src/index.js
+++ b/src/index.js
@@ -30,6 +30,8 @@ function setContent( content, options ) {
} );
}
-setContent.withSelection = function( content, options ) {};
+setContent.withSelection = function( content, options ) {
+
+};
module.exports = setContent;
\ No newline at end of file
diff --git a/test/index.test.js b/test/index.test.js
index <HASH>..<HASH> 100644
--- a/test/index.test.js
+++ b/test/index.test.js
@@ -40,4 +40,11 @@
} );
} );
} );
+
+ suite( 'setContent.withSelection', function() {
+ test( 'It sets the content', function() {
+ return setContent.withSelection( 'foo' )
+ .then( editor => assert.strictEqual( getContent( editor ), 'foo', 'Invalid content') );
+ } );
+ } );
} )();
\ No newline at end of file | Started tests for set conetnt with selection. |
diff --git a/modules/system/classes/MediaLibrary.php b/modules/system/classes/MediaLibrary.php
index <HASH>..<HASH> 100644
--- a/modules/system/classes/MediaLibrary.php
+++ b/modules/system/classes/MediaLibrary.php
@@ -73,10 +73,6 @@ class MediaLibrary
$this->storageFolder = self::validatePath(Config::get('cms.storage.media.folder', 'media'), true);
$this->storagePath = rtrim(Config::get('cms.storage.media.path', '/storage/app/media'), '/');
- if (!starts_with($this->storagePath, ['//', 'http://', 'https://'])) {
- $this->storagePath = Request::getBasePath() . $this->storagePath;
- }
-
$this->ignoreNames = Config::get('cms.storage.media.ignore', FileDefinitions::get('ignoreFiles'));
$this->ignorePatterns = Config::get('cms.storage.media.ignorePatterns', ['^\..*']); | Remove application root relative to domain root from $mediaFinder->storagePath (#<I>)
This gets added later through the use of Url::to(). Credit to @adsa<I>. Fixes #<I>, fixes #<I> |
diff --git a/test/person-test.js b/test/person-test.js
index <HASH>..<HASH> 100644
--- a/test/person-test.js
+++ b/test/person-test.js
@@ -56,7 +56,7 @@ var testSchema = {
"updated",
"upstreamDuplicates",
"url"],
- indices: ["_uuid", "url"]
+ indices: ["_uuid", "url", "image.url"]
};
var testData = { | Add image.url to list of expected indices |
diff --git a/lib/createStandardErrorMessage.js b/lib/createStandardErrorMessage.js
index <HASH>..<HASH> 100644
--- a/lib/createStandardErrorMessage.js
+++ b/lib/createStandardErrorMessage.js
@@ -13,16 +13,14 @@ module.exports = function createStandardErrorMessage(output, subject, testDescri
assertionIndices.push(offset + parsed.args.length - 2);
var assertionName = options.originalArgs[offset + parsed.args.length - 2];
var assertions = options.unexpected.assertions[assertionName];
- var assertion;
- for (var j = 0 ; j < assertions.length ; j += 1) {
- if (assertions[j].parsed.args.some(function (a) { return a.isAssertion; })) {
- assertion = assertions[j];
- break;
+ if (assertions) {
+ for (var j = 0 ; j < assertions.length ; j += 1) {
+ if (assertions[j].parsed.args.some(function (a) { return a.isAssertion; })) {
+ markAssertionIndices(assertions[j].parsed, offset + parsed.args.length - 1);
+ break;
+ }
}
}
- if (assertion) {
- markAssertionIndices(assertion.parsed, offset + parsed.args.length - 1);
- }
}
} | createStandardErrorMessage: Don't break when the assertion pointed to by the argument declared <assertion> does not exist. |
diff --git a/setup.py b/setup.py
index <HASH>..<HASH> 100644
--- a/setup.py
+++ b/setup.py
@@ -22,7 +22,7 @@ from setuptools import setup, find_packages
setup(name='umapi-client',
- version='1.0.0rc5',
+ version='1.0.0',
description='Adobe User Management API (UMAPI) client - see https://adobe.ly/2h1pHgV',
long_description=('The Adobe User Management API (aka the Adobe UMAPI) is an Adobe-hosted network service '
'which provides Adobe Enterprise customers the ability to manage their users. This ' | Promote <I>rc5 to <I>. |
diff --git a/packages/react/src/components/FileUploader/FileUploader.js b/packages/react/src/components/FileUploader/FileUploader.js
index <HASH>..<HASH> 100644
--- a/packages/react/src/components/FileUploader/FileUploader.js
+++ b/packages/react/src/components/FileUploader/FileUploader.js
@@ -298,6 +298,12 @@ export default class FileUploader extends Component {
name: PropTypes.string,
/**
+ * Provide an optional `onChange` hook that is called each time the input is
+ * changed
+ */
+ onChange: PropTypes.func,
+
+ /**
* Provide an optional `onClick` hook that is called each time the button is
* clicked
*/
@@ -347,7 +353,9 @@ export default class FileUploader extends Component {
Array.prototype.map.call(evt.target.files, file => file.name)
),
});
- this.props.onChange(evt);
+ if (this.props.onChange) {
+ this.props.onChange(evt);
+ }
};
handleClick = (evt, index) => { | feat(file-uploader): add support for onChange (#<I>) |
diff --git a/src/Aws/Common/Client/UploadBodyListener.php b/src/Aws/Common/Client/UploadBodyListener.php
index <HASH>..<HASH> 100644
--- a/src/Aws/Common/Client/UploadBodyListener.php
+++ b/src/Aws/Common/Client/UploadBodyListener.php
@@ -16,6 +16,7 @@
namespace Aws\Common\Client;
+use Aws\Common\Exception\InvalidArgumentException;
use Guzzle\Common\Event;
use Guzzle\Http\EntityBody;
use Guzzle\Service\Command\AbstractCommand as Command;
@@ -81,13 +82,13 @@ class UploadBodyListener implements EventSubscriberInterface
$body = fopen($source, 'r');
}
+ // Prepare the body parameter and remove the source file parameter
if (null !== $body) {
- $body = EntityBody::factory($body);
+ $command->remove($this->sourceParameter);
+ $command->set($this->bodyParameter, EntityBody::factory($body));
+ } else {
+ throw new InvalidArgumentException("You must specify a non-null value for the {$this->bodyParameter} or {$this->sourceParameter} parameters.");
}
-
- // Prepare the body parameter and remove the source file parameter
- $command->remove($this->sourceParameter);
- $command->set($this->bodyParameter, $body);
}
}
} | Now throws an exception earlier when a body or source isn't specified for an upload operation. |
diff --git a/holoviews/plotting/mpl/plot.py b/holoviews/plotting/mpl/plot.py
index <HASH>..<HASH> 100644
--- a/holoviews/plotting/mpl/plot.py
+++ b/holoviews/plotting/mpl/plot.py
@@ -164,6 +164,7 @@ class MPLPlot(DimensionedPlot):
bbox_transform=axis.transAxes)
at.patch.set_visible(False)
axis.add_artist(at)
+ self.handles['sublabel'] = at.txt.get_children()[0]
def _finalize_axis(self, key): | Added sublabel to plot handles in mpl backend |
diff --git a/src/Organizations/Options/ImageFileCacheOptions.php b/src/Organizations/Options/ImageFileCacheOptions.php
index <HASH>..<HASH> 100644
--- a/src/Organizations/Options/ImageFileCacheOptions.php
+++ b/src/Organizations/Options/ImageFileCacheOptions.php
@@ -38,7 +38,7 @@ class ImageFileCacheOptions extends AbstractOptions
*
* @var string
*/
- protected $uriPath = '/cache/Organizations/Image';
+ protected $uriPath = '/static/Organizations/Image';
/**
* @param array|Traversable|null $options | Directory "cache" renamed to "static" for organization image cache
#<I> |
diff --git a/Libraries/Column.php b/Libraries/Column.php
index <HASH>..<HASH> 100644
--- a/Libraries/Column.php
+++ b/Libraries/Column.php
@@ -388,7 +388,7 @@ class Column {
$column1 = explode('.', $this->relationshipField->column);
$column1 = $column1[1];
$column2 = explode('.', $this->relationshipField->column2);
- $column2 = $column1[1];
+ $column2 = $column2[1];
$joins .= ' LEFT JOIN '.$int_table.' AS '.$int_alias.' ON '.$int_alias.'.'.$column1.' = '.$field_table.'.'.$model::$key
.' LEFT JOIN '.$other_table.' AS '.$other_alias.' ON '.$other_alias.'.'.$other_key.' = '.$int_alias.'.'.$column2; | just kidding (See #<I>) |
diff --git a/tinymce/views.py b/tinymce/views.py
index <HASH>..<HASH> 100644
--- a/tinymce/views.py
+++ b/tinymce/views.py
@@ -95,4 +95,4 @@ def filebrowser(request):
except:
fb_url = request.build_absolute_uri(reverse('filebrowser:fb_browse'))
return render(request, 'tinymce/filebrowser.js', {'fb_url': fb_url},
- content_type='text/javascript')
+ content_type='application/javascript') | Corrects js mime type in view |
diff --git a/xmantissa/static/js/scrolltable.js b/xmantissa/static/js/scrolltable.js
index <HASH>..<HASH> 100644
--- a/xmantissa/static/js/scrolltable.js
+++ b/xmantissa/static/js/scrolltable.js
@@ -152,6 +152,9 @@ Mantissa.ScrollTable.ScrollingWidget.methods(
cells = MochiKit.Base.map.apply(null, [null].concat(cells))[1];
var rowNode = self.makeRowElement(rowOffset, rowData, cells);
+ rowNode.style.position = "absolute";
+ rowNode.style.top = (rowOffset * self._rowHeight) + "px";
+
self._rows[rowOffset] = [rowData, rowNode];
self._scrollContent.appendChild(rowNode);
}, | apply patch from #<I>. author: moe, reviewer: glyph. fixes issue with scrolltable row positioning. closes #<I> |
Subsets and Splits
No community queries yet
The top public SQL queries from the community will appear here once available.
diff --git a/ratcave/texture.py b/ratcave/texture.py
index <HASH>..<HASH> 100644
--- a/ratcave/texture.py
+++ b/ratcave/texture.py
@@ -85,10 +85,11 @@ class Texture(BaseTexture, ugl.BindTargetMixin):
gl.glFramebufferTexture2DEXT(gl.GL_FRAMEBUFFER_EXT, self.attachment_point, self.target0, self.id, 0)
@classmethod
- def from_image(cls, img_filename, **kwargs):
- """Uses Pyglet's image.load function to generate a Texture from an image file."""
+ def from_image(cls, img_filename, mipmap=True, **kwargs):
+ """Uses Pyglet's image.load function to generate a Texture from an image file. If 'mipmap', then texture will
+ have mipmap layers calculated."""
img = pyglet.image.load(img_filename)
- tex = img.get_texture()
+ tex = img.get_mipmapped_texture() if mipmap else img.get_texture()
gl.glBindTexture(gl.GL_TEXTURE_2D, 0)
return cls(id=tex.id, data=tex, **kwargs) | Added mipmapping from pyglet texture creation from images. |